@@ -18,12 +18,26 @@
 #include <QDebug>
 
 #include "data.h"
+#include "table-model.h"
 
 QT_BEGIN_NAMESPACE
 class QTableWidget;
 class QTableWidgetItem;
 QT_END_NAMESPACE
 
+class CourseWindow: public QMainWindow
+{
+    Q_OBJECT;
+
+public:
+    CourseWindow(QWidget *parent = 0);
+
+    void setup(Course *course);
+
+private:
+    CourseTableModel *model;
+};
+
 class CourseSelectDialog: public QDialog
 {
   Q_OBJECT
