@@ -108,11 +108,14 @@ public:
     Course *getCourse(const QString &courseName);
     bool isEmpty();
     bool isReadOnly();
+    void setHomeClub(bool value) { m_homeClub = value; }
+    bool isHomeClub() { return m_homeClub; }
 
     QList <Course *> getCourseList() { return courseList; } // HACK: fixme
 
 private:
     bool m_readOnly;
+    bool m_homeClub;
     QList <Course *> courseList;
     QString name;
 };
