@@ -34,20 +34,22 @@ QString masterFile;
 QString logFile("/tmp/scorecard.log");
 QString titleScores("ScoreCard - Scores");
 QString titleCourses("ScoreCard - Courses");
-QString settingsGroup("Settings");
-QString settingsHcp("hcp");
-QString settingsHomeClub("home-club");
-QString settingsDefaultCourses("default-courses");
 
 bool dateLessThan(const Score *s1, const Score *s2)
 {
-  return (*s1) < (*s2);
+    return (*s1) < (*s2);
 }
 
 bool dateMoreThan(const Score *s1, const Score *s2)
 {
-  return (*s1) > (*s2);
+    return (*s1) > (*s2);
 }
+
+bool scoreMoreThan(const Score *s1, const Score *s2)
+{
+    return s1->getTotal(Total) > s2->getTotal(Total);
+}
+
 // Find score based on club and course name
 Score *MainWindow::findScore(QString & clubName, QString & courseName)
 {
@@ -145,84 +147,113 @@ void MainWindow::flushReadOnlyItems()
     }
 }
 
+void MainWindow::markHomeClub()
+{
+    TRACE;
+    QListIterator<Club *> i(clubList);
+    Club *c;
+
+    while (i.hasNext()) {
+        c = i.next();
+        if (c->getName() == conf.homeClub)
+            c->setHomeClub(true);
+        else
+            c->setHomeClub(false);
+    }
+}
+
+void MainWindow::sortScoreList()
+{
+    if (conf.sortOrder == "Date")
+        qSort(scoreList.begin(), scoreList.end(), dateMoreThan); 
+    else if (conf.sortOrder == "Score")
+        qSort(scoreList.begin(), scoreList.end(), scoreMoreThan); 
+}
 
 MainWindow::MainWindow(QMainWindow *parent): QMainWindow(parent)
 {
-  resize(800, 480);
+    resize(800, 480);
 
 #ifdef Q_WS_MAEMO_5
-  setAttribute(Qt::WA_Maemo5StackedWindow);
+    setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
-  loadSettings();
+    loadSettings();
 
-  centralWidget = new QWidget(this);
+    centralWidget = new QWidget(this);
 
-  setCentralWidget(centralWidget);
+    setCentralWidget(centralWidget);
 
-  loadScoreFile(scoreFile, scoreList);
-  if (conf.defaultCourses == "Yes")
-      loadClubFile(masterFile, clubList, true);
-  loadClubFile(clubFile, clubList);
+    loadScoreFile(scoreFile, scoreList);
+    if (conf.defaultCourses == "Yes")
+        loadClubFile(masterFile, clubList, true);
+    loadClubFile(clubFile, clubList);
+    markHomeClub();
 
-  // Sort the scores based on dates
-  qSort(scoreList.begin(), scoreList.end(), dateMoreThan); 
-  createActions();
-  createMenus();
+    // Sort the scores based on settings
+    sortScoreList();
 
-  createListView(scoreList, clubList);
+    createActions();
+    createMenus();
 
-  createLayoutList(centralWidget);
+    createListView(scoreList, clubList);
 
-  scoreWindow = new ScoreWindow(this);
-  courseWindow = new CourseWindow(this);
+    createLayoutList(centralWidget);
+
+    scoreWindow = new ScoreWindow(this);
+    courseWindow = new CourseWindow(this);
 }
 
 void MainWindow::loadSettings(void)
 {
     TRACE;
-  bool external = false;
+    bool external = false;
 
-  QDir mmc(mmcDir);
-  if (mmc.exists())
-    external = true;
+    QDir mmc(mmcDir);
+    if (mmc.exists())
+        external = true;
 
-  // TODO: make via user option, automatic will never work
-  external = false;
+    // TODO: make via user option, automatic will never work
+    external = false;
 
 #ifndef Q_WS_MAEMO_5
-  dataDir = "./" + dataDirName;
+    dataDir = "./" + dataDirName;
 #else
-  if (external) {
-    dataDir = mmcDir + "/" + appName + "/" + dataDirName;
-  }
-  else {
-    dataDir = topDir + "/" + appName + "/" + dataDirName;
-  }
-#endif
-  scoreFile = dataDir + "/" + scoreFileName;
-  clubFile = dataDir + "/" + clubFileName;
-  masterFile = dataDir + "/" + masterFileName;
-
-  QDir dir(dataDir);
-  if (!dir.exists())
-    if (!dir.mkpath(dataDir)) {
-      qWarning() << "Unable to create: " + dataDir;
-      return;
+    if (external) {
+        dataDir = mmcDir + "/" + appName + "/" + dataDirName;
     }
-  qDebug() << "Data is at:" + dataDir;
+    else {
+        dataDir = topDir + "/" + appName + "/" + dataDirName;
+    }
+#endif
+    scoreFile = dataDir + "/" + scoreFileName;
+    clubFile = dataDir + "/" + clubFileName;
+    masterFile = dataDir + "/" + masterFileName;
 
-  settings.beginGroup(settingsGroup);
-  conf.hcp = settings.value(settingsHcp);
-  conf.homeClub = settings.value(settingsHomeClub);
-  conf.defaultCourses = settings.value(settingsDefaultCourses);
-  settings.endGroup();
+    QDir dir(dataDir);
+    if (!dir.exists())
+        if (!dir.mkpath(dataDir)) {
+            qWarning() << "Unable to create: " + dataDir;
+            return;
+        }
+    qDebug() << "Data is at:" + dataDir;
 
-  // Use default courses if no settings for that
-  if (!conf.defaultCourses.isValid())
-      conf.defaultCourses = "Yes";
+    settings.beginGroup(settingsGroup);
+    conf.hcp = settings.value(settingsHcp);
+    conf.homeClub = settings.value(settingsHomeClub);
+    conf.sortOrder = settings.value(settingsSortOrder);
+    conf.defaultCourses = settings.value(settingsDefaultCourses);
+    settings.endGroup();
 
-  qDebug() << "Settings: " << conf.hcp << conf.homeClub << conf.defaultCourses;
+    // Use default courses if no settings for that
+    if (!conf.defaultCourses.isValid())
+        conf.defaultCourses = "Yes";
+
+    // Use date sort order if no settings for that
+    if (!conf.sortOrder.isValid())
+        conf.sortOrder = "Yes";
+
+    qDebug() << "Settings: " << conf.hcp << conf.homeClub << conf.sortOrder << conf.defaultCourses;
 }
 
 void MainWindow::saveSettings(void)
@@ -233,6 +264,8 @@ void MainWindow::saveSettings(void)
         settings.setValue(settingsHcp, conf.hcp);
     if (conf.homeClub.isValid())
         settings.setValue(settingsHomeClub, conf.homeClub);
+    if (conf.sortOrder.isValid())
+        settings.setValue(settingsSortOrder, conf.sortOrder);
     if (conf.defaultCourses.isValid())
         settings.setValue(settingsDefaultCourses, conf.defaultCourses);
     settings.endGroup();
@@ -258,7 +291,7 @@ void MainWindow::createListView(QList<Score *> &scoreList,
     scoreListModel = new ScoreListModel(scoreList, clubList);
     courseListModel = new CourseListModel(clubList);
 
-    list->setStyleSheet(ScoreStyle::style());
+    list->setStyleSheet(defaultStyleSheet);
 
     list->setSelectionMode(QAbstractItemView::SingleSelection);
     list->setProperty("FingerScrolling", true);
@@ -417,8 +450,8 @@ void MainWindow::newScore()
             Score *score = new Score(scores, clubName, courseName, date);
             scoreList << score;
 
-            // Sort the scores based on dates
-            qSort(scoreList.begin(), scoreList.end(), dateMoreThan); 
+            // Sort the scores based on settings
+            sortScoreList();
             // Save it
             saveScoreFile(scoreFile, scoreList);
             scoreListModel->update(scoreList);
@@ -615,39 +648,39 @@ void MainWindow::deleteCourse()
 void MainWindow::viewStatistics()
 {
     TRACE;
-  QMainWindow *win = new QMainWindow(this);
-  QString title = "Statistics";
-  win->setWindowTitle(title);
+    QMainWindow *win = new QMainWindow(this);
+    QString title = "Statistics";
+    win->setWindowTitle(title);
 #ifdef Q_WS_MAEMO_5
-  win->setAttribute(Qt::WA_Maemo5StackedWindow);
+    win->setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
-  StatModel *model = new StatModel(clubList, scoreList);
+    StatModel *model = new StatModel(clubList, scoreList);
 
-  QTableView *table = new QTableView;
-  table->showGrid();
-  table->setSelectionMode(QAbstractItemView::NoSelection);
-  table->setStyleSheet(ScoreStyle::style());
-  table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
-  table->verticalHeader()->setResizeMode(QHeaderView::Stretch);
-  table->verticalHeader()->setAutoFillBackground(true);
-  table->setModel(model);
+    QTableView *table = new QTableView;
+    table->showGrid();
+    table->setSelectionMode(QAbstractItemView::NoSelection);
+    table->setStyleSheet(statStyleSheet);
+    table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+    table->verticalHeader()->setResizeMode(QHeaderView::Stretch);
+    table->verticalHeader()->setAutoFillBackground(true);
+    table->setModel(model);
 
-  QWidget *central = new QWidget(win);
-  win->setCentralWidget(central);
+    QWidget *central = new QWidget(win);
+    win->setCentralWidget(central);
 
-  QTextEdit *textEdit = new QTextEdit;
+    QTextEdit *textEdit = new QTextEdit;
 
-  textEdit->setReadOnly(true);
+    textEdit->setReadOnly(true);
 
-  QVBoxLayout *infoLayout = new QVBoxLayout;
-  infoLayout->addWidget(table);
+    QVBoxLayout *infoLayout = new QVBoxLayout;
+    infoLayout->addWidget(table);
 
-  QHBoxLayout *mainLayout = new QHBoxLayout(central);
-  mainLayout->addLayout(infoLayout);
-  central->setLayout(mainLayout);
+    QHBoxLayout *mainLayout = new QHBoxLayout(central);
+    mainLayout->addLayout(infoLayout);
+    central->setLayout(mainLayout);
 
-  win->show();
+    win->show();
 }
 
 void MainWindow::viewSettings()
@@ -664,8 +697,6 @@ void MainWindow::viewSettings()
         QString newValue = conf.defaultCourses.toString();
         saveSettings();
 
-        qDebug() << "Settings:" << oldValue << "->" << newValue;
-
         // Reload club list, or drop r/o courses from list
         if (oldValue == "Yes" && newValue == "No") {
             flushReadOnlyItems();
@@ -677,26 +708,31 @@ void MainWindow::viewSettings()
             courseListModel->update(clubList);
             list->update();
         }
+        // TODO: do these only if needed
+        markHomeClub();
+        sortScoreList();
+        scoreListModel->update(scoreList);
+        list->update();
     }
 }
 
 void MainWindow::loadScoreFile(QString &fileName, QList<Score *> &list)
 {
-  ScoreXmlHandler handler(list);
+    ScoreXmlHandler handler(list);
 
-  if (handler.parse(fileName))
-    qDebug() << "File loaded:" << fileName << " entries:" << list.size();
+    if (handler.parse(fileName))
+        qDebug() << "File loaded:" << fileName << " entries:" << list.size();
 }
 
 void MainWindow::saveScoreFile(QString &fileName, QList<Score *> &list)
 {
-  ScoreXmlHandler handler(list);
+    ScoreXmlHandler handler(list);
 
-  if (handler.save(fileName))
-    // TODO: banner
-    qDebug() << "File saved:" << fileName << " entries:" << list.size();
-  else
-    qWarning() << "Unable to save:" << fileName;
+    if (handler.save(fileName))
+        // TODO: banner
+        qDebug() << "File saved:" << fileName << " entries:" << list.size();
+    else
+        qWarning() << "Unable to save:" << fileName;
 }
 
 void MainWindow::loadClubFile(QString &fileName, QList<Club *> &list, bool readOnly)
@@ -709,12 +745,11 @@ void MainWindow::loadClubFile(QString &fileName, QList<Club *> &list, bool readO
 
 void MainWindow::saveClubFile(QString &fileName, QList<Club *> &list)
 {
-  ClubXmlHandler handler(list);
-
-  if (handler.save(fileName))
-    // TODO: banner
-    qDebug() << "File saved:" << fileName << " entries:" << list.size();
-  else
-    qWarning() << "Unable to save:" << fileName;
+    ClubXmlHandler handler(list);
 
+    if (handler.save(fileName))
+        // TODO: banner
+        qDebug() << "File saved:" << fileName << " entries:" << list.size();
+    else
+        qWarning() << "Unable to save:" << fileName;
 }
