@@ -56,6 +56,22 @@ void SettingsDialog::createLayout(QWidget *parent)
     homeClubButton->setPickSelector(listPickSelector2);
     homeClubButton->setText(QString::fromUtf8("Home Club"));
 
+    // Sort Order
+    sortButton = new QMaemo5ValueButton();
+    sortButton->setValueLayout(QMaemo5ValueButton::ValueBesideText);
+    QMaemo5ListPickSelector * listPickSelector4 = new QMaemo5ListPickSelector;
+    QStringList sortList;
+    sortList << "Date" << "Score";
+    sortModel = new QStandardItemModel(sortList.count(), 0);
+    for (int i = 0; i < sortList.count(); i++) {
+        item = new QStandardItem(QString("%0").arg(sortList.at(i)));
+        item->setTextAlignment(Qt::AlignCenter);
+        sortModel->setItem(i, item);
+    }
+    listPickSelector4->setModel(sortModel);
+    sortButton->setPickSelector(listPickSelector4);
+    sortButton->setText(QString::fromUtf8("Sort Order"));
+
     // Use Default Courses
     defaultCoursesButton = new QMaemo5ValueButton();
     defaultCoursesButton->setValueLayout(QMaemo5ValueButton::ValueBesideText);
@@ -74,6 +90,7 @@ void SettingsDialog::createLayout(QWidget *parent)
 
     leftLayout->addWidget(hcpButton);
     leftLayout->addWidget(homeClubButton);
+    leftLayout->addWidget(sortButton);
     leftLayout->addWidget(defaultCoursesButton);
 #endif
 
@@ -101,7 +118,7 @@ void SettingsDialog::init(AppSettings &conf, QList<Club *> &list)
     }
 
     QListIterator<Club *> i(clubList);
-
+    
     while (i.hasNext()) {
         Club *club = i.next();
         QStandardItem *item = new QStandardItem(QString("%0").arg(club->getName()));
@@ -114,6 +131,12 @@ void SettingsDialog::init(AppSettings &conf, QList<Club *> &list)
         index++;
     }
 
+    if (conf.sortOrder.isValid()) {
+        int index = conf.sortOrder.toString() == "Date" ? 0 : 1;
+        sel = (QMaemo5ListPickSelector *)sortButton->pickSelector();
+        sel->setCurrentIndex(index);
+    }
+
     if (conf.defaultCourses.isValid()) {
         int index = conf.defaultCourses.toString() == "Yes" ? 0 : 1;
         sel = (QMaemo5ListPickSelector *)defaultCoursesButton->pickSelector();
@@ -139,6 +162,11 @@ void SettingsDialog::results(AppSettings &conf)
         item = homeClubModel->item(sel->currentIndex());
         conf.homeClub = item->data(Qt::DisplayRole);
     }
+    sel = (QMaemo5ListPickSelector *)sortButton->pickSelector();
+    if (sel->currentIndex() != -1) {
+        item = sortModel->item(sel->currentIndex());
+        conf.sortOrder = item->data(Qt::DisplayRole);
+    }
     sel = (QMaemo5ListPickSelector *)defaultCoursesButton->pickSelector();
     if (sel->currentIndex() != -1) {
         item = defaultCoursesModel->item(sel->currentIndex());
